@@ -103,7 +103,7 @@ HV* export_timezone (pTHX_ const Timezone* zone) {
     hv_store(ret, "future", 6, newRV_noinc((SV*) future), 0);
     
     AV* trans = newAV();
-    for (int i = 0; i < zone->trans_cnt; i++) av_push(trans, export_transition(aTHX_ zone->trans[i], false));
+    for (uint32_t i = 0; i < zone->trans_cnt; i++) av_push(trans, export_transition(aTHX_ zone->trans[i], false));
     hv_store(ret, "transitions", 11, newRV_noinc((SV*) trans), 0);
     
     hv_store(ret, "past", 4, export_transition(aTHX_ zone->trans[0], true), 0);
